==> spam-0.3.1-cp36-cp36m-manylinux1_x86_64.whl: spam/label/src/setVoronoi.cpp <==
#include <stdio.h>
#include <math.h>
#include <iostream>
#include "labelToolkitC.hpp"

#define MAX(x, y) (((x) > (y)) ? (x) : (y))
#define MIN(x, y) (((x) < (y)) ? (x) : (y))


/* 2018-03-27 -- Edward Andò and Takashi Matsishima
 *  Approximate set Voronoi calculator
 *
 * This function takes in:
 *    - labelled 3D image where the object of interest are labelled as non-zero labels::label
 *    - a float image of the same size representing an EDT of the pores -- this can come from:
 *          scipy.ndimage.morphology.distance_transform_edt( lab == 0 ).astype( '<f4' )
 *    - a labels::label 3D array out for the labelled voxels
 */


void setVoronoi(    int volSizeZ1,  int volSizeY1, int volSizeX1,   labels::label* volLab,
                    int volSizeZ2,  int volSizeY2, int volSizeX2,           float* poreEDT,
                    int volSizeZ3,  int volSizeY3, int volSizeX3,   labels::label* volLabOut,
                    int nSphereP,   int three,                                int* indicesSorted,
                    int distThreshPlusOne,                                    int* indices
//                     float distThresh
                    )
{

    float distThresh = (float) distThreshPlusOne - 1;
    unsigned short distThreshUS = (unsigned short) distThresh;

    for ( unsigned short z = distThreshUS; z <= volSizeZ1-1-distThreshUS; z++ )
    {
//         printf( "\r\tSet Voronoi progress: \t\t%02.1f%%\t", 100 * (float)(z-distThreshUS+1) / (float)(volSizeZ1-2*distThreshUS) );

        # pragma omp parallel
        # pragma omp for
        for ( unsigned short y = distThreshUS; y <= volSizeY1-1-distThreshUS; y++ )
        {
            for ( unsigned short x = distThreshUS; x <= volSizeX1-1-distThreshUS; x++ )
            {
                unsigned long int index_i = z  * volSizeX1 * volSizeY1   +   y * volSizeX1   +   x;

                float EDTval = poreEDT[ index_i ];

                unsigned int radiusMin = floor( EDTval );
                unsigned int radiusMax = ceil(  EDTval );

                /* In case we're on a perfect int */
                if ( radiusMin == radiusMax ) radiusMax++;

                /* If value of the pore's EDT is smaller than our time-saving threshold and is not zero */
                if ( EDTval < distThresh && EDTval > 0)
                {
                    /* Previous we raster scanned, now used sorted distances to
                     *  access elements in the right order.
                     *
                     * First of all: use the indices matrix to figure out our entry point and
                     *  end point for our scan */
                    for ( int distIndex = indices[radiusMin]; distIndex <= indices[radiusMax]; distIndex++ )
                    {
                        int Zrel = indicesSorted[ 3*distIndex + 0 ];
                        int Yrel = indicesSorted[ 3*distIndex + 1 ];
                        int Xrel = indicesSorted[ 3*distIndex + 2 ];
                        unsigned long int index_l = (z+Zrel)  * volSizeX1 * volSizeY1   +   (y+Yrel) * volSizeX1   +   (x+Xrel);
                        if ( volLab[ index_l ] != 0 )
                        {
                            volLabOut[ index_i ] = volLab[ index_l ];
                            break;
                        }
                    }

//                     /* Local loop around + and - radiusMax */
//                     for ( int Z = -radiusMax; Z <= radiusMax; Z++ )
//                     {
//                         for ( int Y = -radiusMax; Y <= radiusMax; Y++ )
//                         {
//                             for ( int X = -radiusMax; X <= radiusMax; X++ )
//                             {
//                                 /* Compute distance to central voxel -- keep it squared to avoid slow sqrt*/
//                                 float distSq = ( Z * Z ) + ( Y * Y ) + ( X * X );
// 
//                                 /* if within radii coniditions*/
//                                 if ( distSq > radiusMin &&  distSq < closestDistanceSq )
//                                 {
//                                     unsigned long int index_l = (z+Z)  * volSizeX1 * volSizeY1   +   (y+Y) * volSizeX1   +   (x+X);
//                                     if ( volLab[ index_l ] != 0 && distSq < closestDistanceSq )
//                                     {
//                                         closestDistanceSq = distSq;
//                                         labelOut = volLab[ index_l ];
//                                     }
//                                 }
//                             }
//                         }
//                     }
//                     volLabOut[ index_i ] = labelOut;
                }

                /* We're already inside a given label, just copy it */
                if ( EDTval == 0 )
                {
                    volLabOut[ index_i ] = volLab[ index_i ];
                }
            }
        }
    }

//     printf( "\n" );
}

==> spam-0.3.2.1-cp36-cp36m-manylinux1_x86_64.whl: spam/label/src/setVoronoi.cpp <==
#include <stdio.h>
#include <math.h>
#include <iostream>
#include "labelToolkitC.hpp"

#define MAX(x, y) (((x) > (y)) ? (x) : (y))
#define MIN(x, y) (((x) < (y)) ? (x) : (y))


/* 2018-03-27 -- Edward Andò and Takashi Matsishima
 *  Approximate set Voronoi calculator
 *
 * This function takes in:
 *    - labelled 3D image where the object of interest are labelled as non-zero labels::label
 *    - a float image of the same size representing an EDT of the pores -- this can come from:
 *          scipy.ndimage.morphology.distance_transform_edt( lab == 0 ).astype( '<f4' )
 *    - a labels::label 3D array out for the labelled voxels
 */


void setVoronoi(    int volSizeZ1,  int volSizeY1, int volSizeX1,   labels::label* volLab,
                    int volSizeZ2,  int volSizeY2, int volSizeX2,           float* poreEDT,
                    int volSizeZ3,  int volSizeY3, int volSizeX3,   labels::label* volLabOut,
                    int nSphereP,   int three,                                int* indicesSorted,
                    int distThreshPlusOne,                                    int* indices
//                     float distThresh
                    )
{

    float distThresh = (float) distThreshPlusOne - 1;
    unsigned short distThreshUS = (unsigned short) distThresh;

    for ( size_t z = distThreshUS; z <= volSizeZ1-1-distThreshUS; z++ )
    {
//         printf( "\r\tSet Voronoi progress: \t\t%02.1f%%\t", 100 * (float)(z-distThreshUS+1) / (float)(volSizeZ1-2*distThreshUS) );

        # pragma omp parallel
        # pragma omp for
        for ( size_t y = distThreshUS; y <= volSizeY1-1-distThreshUS; y++ )
        {
            for ( size_t x = distThreshUS; x <= volSizeX1-1-distThreshUS; x++ )
            {
                size_t index_i = z  * volSizeX1 * volSizeY1   +   y * volSizeX1   +   x;

                float EDTval = poreEDT[ index_i ];

                unsigned int radiusMin = floor( EDTval );
                unsigned int radiusMax = ceil(  EDTval );

                /* In case we're on a perfect int */
                if ( radiusMin == radiusMax ) radiusMax++;

                /* If value of the pore's EDT is smaller than our time-saving threshold and is not zero */
                if ( EDTval < distThresh && EDTval > 0)
                {
                    /* Previous we raster scanned, now used sorted distances to
                     *  access elements in the right order.
                     *
                     * First of all: use the indices matrix to figure out our entry point and
                     *  end point for our scan */
                    for ( int distIndex = indices[radiusMin]; distIndex <= indices[radiusMax]; distIndex++ )
                    {
                        int Zrel = indicesSorted[ 3*distIndex + 0 ];
                        int Yrel = indicesSorted[ 3*distIndex + 1 ];
                        int Xrel = indicesSorted[ 3*distIndex + 2 ];
                        unsigned long int index_l = (z+Zrel)  * volSizeX1 * volSizeY1   +   (y+Yrel) * volSizeX1   +   (x+Xrel);
                        if ( volLab[ index_l ] != 0 )
                        {
                            volLabOut[ index_i ] = volLab[ index_l ];
                            break;
                        }
                    }

//                     /* Local loop around + and - radiusMax */
//                     for ( int Z = -radiusMax; Z <= radiusMax; Z++ )
//                     {
//                         for ( int Y = -radiusMax; Y <= radiusMax; Y++ )
//                         {
//                             for ( int X = -radiusMax; X <= radiusMax; X++ )
//                             {
//                                 /* Compute distance to central voxel -- keep it squared to avoid slow sqrt*/
//                                 float distSq = ( Z * Z ) + ( Y * Y ) + ( X * X );
// 
//                                 /* if within radii coniditions*/
//                                 if ( distSq > radiusMin &&  distSq < closestDistanceSq )
//                                 {
//                                     unsigned long int index_l = (z+Z)  * volSizeX1 * volSizeY1   +   (y+Y) * volSizeX1   +   (x+X);
//                                     if ( volLab[ index_l ] != 0 && distSq < closestDistanceSq )
//                                     {
//                                         closestDistanceSq = distSq;
//                                         labelOut = volLab[ index_l ];
//                                     }
//                                 }
//                             }
//                         }
//                     }
//                     volLabOut[ index_i ] = labelOut;
                }

                /* We're already inside a given label, just copy it */
                if ( EDTval == 0 )
                {
                    volLabOut[ index_i ] = volLab[ index_i ];
                }
            }
        }
    }

//     printf( "\n" );
}
